@@ -1,24 +1,8 @@
 # frozen_string_literal: true
 
-# Copyright, 2018, by Samuel G. D. Williams. <http://www.codeotaku.com>
-# 
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-# 
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-# 
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# Released under the MIT License.
+# Copyright, 2019-2022, by Samuel Williams.
+# Copyright, 2020, by Bruno Sutic.
 
 require 'protocol/http/headers'
 
@@ -334,7 +318,7 @@ module Protocol
 					@stream.flush unless body.ready?
 				end
 				
-				if trailer
+				if trailer&.any?
 					@stream.write("0\r\n")
 					write_headers(trailer)
 					@stream.write("\r\n")
@@ -366,10 +350,19 @@ module Protocol
 			end
 			
 			def write_body(version, body, head = false, trailer = nil)
+				# HTTP/1.0 cannot in any case handle trailers.
+				if version == HTTP10 # or te: trailers was not present (strictly speaking not required.)
+					trailer = nil
+				end
+				
+				# While writing the body, we don't know if trailers will be added. We must choose a different body format depending on whether there is the chance of trailers, even if trailer.any? is currently false.
+				#
+				# Below you notice `and trailer.nil?`. I tried this but content-length is more important than trailers.
+				
 				if body.nil?
 					write_connection_header(version)
 					write_empty_body(body)
-				elsif length = body.length and trailer.nil?
+				elsif length = body.length # and trailer.nil?
 					write_connection_header(version)
 					write_fixed_length_body(body, length, head)
 				elsif body.empty?
